import {connect} from "react-redux";
import styled from 'styled-components';
import {useEffect, useState} from "react";
import {
    setActiveUserAllPosts,
    setUserDataAsync,
    setActiveUserAllPostsAsync
} from "../store/actionCreators/ActionCreators";
import avatar from "../assets/img/avatarGolub.jpg";
import PostPreview from "./PostPreview";
import UserInfoBlock from "./UserInfoBlock";
import ModalWindow from "./ModalWindow";
import UserList from "./UserList";
import SubscribeButton from "./SubscribeButton";


const UserContentWrapper = styled.div`
  margin-top: 30px;
  width: 100%;
  display: flex;
  align-items: center;
  flex-direction: column;
`
const AvatarBlock = styled.div`
  display: flex;
  flex-direction: column;
  justify-content: space-around;
  align-items: center;
  margin-right: 100px;
`
const PostsContainer = styled.div`
  display: flex;
  flex-direction: row;
  max-width: 1000px;
  flex-wrap: wrap;
  justify-content: center;
`
const UserInfoWrapper = styled.div`
  display: flex;
  width: 1000px;
  justify-content: center;
  margin-bottom: 30px;
  padding-bottom: 20px;
`
const UserInfoBlockWrapper = styled.div`
  display: flex;
  justify-content: flex-start;
  align-items: center;
`
const AvatarWrapper = styled.div`
  width: 100px;
  height: 100px;
  border-radius: 50%;
  border: 1px solid grey;
  overflow: hidden;
  display: flex;
  align-items: center;
`
const UserListWrapper = styled.div`
  width: 30vw;
  height: 50vh;
  display: flex;
`

const tempUser = "62c1cc5e4535fc62e2a185ad"; // test - should be deleted


function UserContent(props) {
    const [isModal, setModal] = useState(false);
    const [userList, setUserList] = useState("");

    // console.log(props.activeUser?._id === props.id)
    useEffect(() => {
        if (!props.activeUser) {
            props.setUserDataAsync(props.id)
        }
        if (props.activeUser && props.activeUserPosts === null) {
            // props.setActiveUserAllPostsAsync(tempUser);

            props.setActiveUserAllPostsAsync(props.activeUser._id)
        }
    })

    useEffect(()=>{
        if(props.activeUserPosts && props.activeUserPosts[0] && props.activeUserPosts[0].owner && props.activeUser && props.activeUserPosts[0].owner._id !== props.activeUser._id ){
            // console.log("2 useEffect")
            props.setActiveUserAllPosts(null)
        }
    })

    // console.log(props.activeUserPosts)

    function toggleModalWindow(userList) {
        setModal(!isModal)

        setUserList(userList)
        // console.log(props.activeUser.followers)
    }
// console.log(props.activeUser?.followers)
    return (
        <>
            {props.activeUser && <UserContentWrapper>
                <UserInfoWrapper>
                    <AvatarBlock>
                        <AvatarWrapper>
                            <img style={{height: "100%"}}
                                 src={props.activeUser && props.activeUser.avatar ? props.activeUser.avatar.url : avatar}
                                 alt={"avatar"}/>
                        </AvatarWrapper>
                        <h2>{props.activeUser.login}</h2>
                    </AvatarBlock>
                    <UserInfoBlockWrapper>
                        <UserInfoBlock count={props.activeUserPosts?.length} description={"posts"}/>
                        <div onClick={()=>toggleModalWindow( props.activeUser.followers)}>
                            <UserInfoBlock count={props.activeUser.followers?.length} description={"followers"}/>
                        </div>
                        <div onClick={()=>toggleModalWindow( props.activeUser.following)}>
                            <UserInfoBlock count={props.activeUser.following?.length} description={"followings"}/>
                        </div>
                    </UserInfoBlockWrapper>


                    {props.activeUser?._id === props.id && <button>fix profile</button> || <SubscribeButton followers={props.activeUser?.followers}/>}


                </UserInfoWrapper>

                {props.activeUserPosts &&
                <PostsContainer>
                    {props.activeUserPosts.map((post, index) => <PostPreview activeUser={props.activeUser}
                                                                             postId={post._id} key={index}/>)}
                </PostsContainer>}
                {isModal && <ModalWindow closeModal={toggleModalWindow}>
                    <UserListWrapper>
                        <UserList users={userList} closeModal={toggleModalWindow}/>
                    </UserListWrapper>
                </ModalWindow>}

            </UserContentWrapper>
            }
        </>
    )
}


const mapStateToProps = (state) => {
    return {
        id: state.auth.user.sub.id,
        activeUser: state.activeUser,
        activeUserPosts: state.activeUserPosts,
    }
}

const mapDispatchToProps = (dispatch) => {
    return {
        setUserDataAsync: (id) => dispatch(setUserDataAsync(id)),
        setActiveUserAllPostsAsync: (id) => dispatch(setActiveUserAllPostsAsync(id)),
        setActiveUserAllPosts: (posts) => dispatch(setActiveUserAllPosts(posts))
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(UserContent);